GradientElevatedButton class

A custom Material Design "gradient elevated button".

Use gradient elevated buttons to enhance visual appeal in flat layouts or to add emphasis to key actions. Gradient buttons are especially suitable for modern designs or vibrant themes.

A gradient elevated button displays a label child on a Material widget with a gradient-filled background. The button's elevation increases when pressed. The gradient is specified using the gradient parameter, and the label's Text and Icon widgets use the GradientButtonStyle.foregroundColor.

This button's style can be customized using its style parameter. A consistent style for all gradient elevated buttons in a subtree can be applied using a custom theme.

If onPressed and onLongPress callbacks are null, the button will be disabled.

Inheritance

Constructors

GradientElevatedButton({Key? key, required VoidCallback? onPressed, VoidCallback? onLongPress, ValueChanged<bool>? onHover, ValueChanged<bool>? onFocusChange, GradientButtonStyle? style, FocusNode? focusNode, bool autofocus = false, Clip? clipBehavior, WidgetStatesController? statesController, required Widget? child, IconAlignment iconAlignment = IconAlignment.start})
Create an GradientElevatedButton.
const
GradientElevatedButton.icon({Key? key, required VoidCallback? onPressed, VoidCallback? onLongPress, ValueChanged<bool>? onHover, ValueChanged<bool>? onFocusChange, GradientButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, WidgetStatesController? statesController, Widget? icon, required Widget label, IconAlignment iconAlignment = IconAlignment.start})
Create an gradient elevated button from a pair of widgets that serve as the button's icon and label.
factory

Properties

autofocus bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
child Widget?
Typically the button's label.
finalinherited
clipBehavior Clip?
The content will be clipped (or not) according to this option.
finalinherited
enabled bool
Whether the button is enabled or disabled.
no setterinherited
focusNode FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
iconAlignment IconAlignment
finalinherited
isSemanticButton bool?
Determine whether this subtree represents a button.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFocusChange ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onHover ValueChanged<bool>?
Called when a pointer enters or exits the button response area.
finalinherited
onLongPress VoidCallback?
Called when the button is long-pressed.
finalinherited
onPressed VoidCallback?
Called when the button is tapped or otherwise activated.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statesController WidgetStatesController?
Represents the interactive "state" of this widget in terms of a set of WidgetStates, like WidgetState.pressed and WidgetState.focused.
finalinherited
style GradientButtonStyle?
Customizes this button's appearance.
finalinherited
tooltip String?
Text that describes the action that will occur when the button is pressed or hovered over.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GradientButtonStyleButton>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultStyleOf(BuildContext context) GradientButtonStyle
Defines the button's default appearance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
themeStyleOf(BuildContext context) GradientButtonStyle?
Returns the GradientElevatedButtonThemeData.style of the closest GradientElevatedButtonTheme ancestor.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

styleFrom({Color? foregroundColor, Gradient? gradient, Gradient? backgroundGradient, Color? disabledForegroundColor, Gradient? disabledBackgroundGradient, Color? disabledBackgroundColor, Color? shadowColor, Color? surfaceTintColor, Color? iconColor, double? iconSize, Color? disabledIconColor, Color? overlayColor, double? elevation, TextStyle? textStyle, EdgeInsetsGeometry? padding, Size? minimumSize, Size? fixedSize, Size? maximumSize, BorderSide? side, OutlinedBorder? shape, MouseCursor? enabledMouseCursor, MouseCursor? disabledMouseCursor, VisualDensity? visualDensity, MaterialTapTargetSize? tapTargetSize, Duration? animationDuration, bool? enableFeedback, AlignmentGeometry? alignment, InteractiveInkFeatureFactory? splashFactory}) GradientButtonStyle
A static convenience method that constructs an elevated button GradientButtonStyle given simple values.