GradientElevatedButtonThemeData class
- Mixed-in types
- Annotations
Constructors
- GradientElevatedButtonThemeData({GradientButtonStyle? style})
-
Creates an GradientElevatedButtonThemeData.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GradientButtonStyle?
-
Overrides for ElevatedButton's default style.
final
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
GradientElevatedButtonThemeData? a, GradientElevatedButtonThemeData? b, double t) → GradientElevatedButtonThemeData? - Linearly interpolate between two elevated button themes.