GradientButtonThemeExtension class
A ThemeExtension for gradient button theming. Use this in ThemeData.extensions.
- Inheritance
-
- Object
- ThemeExtension<
GradientButtonThemeExtension> - GradientButtonThemeExtension
- Annotations
Constructors
- GradientButtonThemeExtension({GradientButtonStyle? style})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → GradientButtonStyle?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{GradientButtonStyle? style}) → GradientButtonThemeExtension -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< GradientButtonThemeExtension> ? other, double t) → GradientButtonThemeExtension -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → GradientButtonStyle?